from distutils.core import  setup


setup(

    name   = 'pysproject1',
    version = '1.2.0',
    py_modules = ['pysproject1'],
    author = 'pys2moving',
    author_email = '1029384008@qq.com',
    url = 'https://github.com/Wison2moving',
    description = 'A simple printer of nested list',
    
    )
